// Copyright 2022 Esri
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.


import SwiftUI

import ArcGIS

import CoreLocation

struct ContentView: View {

    private let map = Map(basemapStyle: .arcGISTopographic)

    private let locationDisplay = LocationDisplay(dataSource: SystemLocationDataSource())

    @State private var failedToStart = false



    var body: some View {
        MapView(map: map)

            .locationDisplay(locationDisplay)

            .task {
                let locationManager = CLLocationManager()
                if locationManager.authorizationStatus == .notDetermined {
                    locationManager.requestWhenInUseAuthorization()
                }

                do {
                    try await locationDisplay.dataSource.start()

                    locationDisplay.initialZoomScale = 40_000
                    locationDisplay.autoPanMode = .recenter

                } catch {

                    self.failedToStart = true

                }

            }

            .alert("Location display failed to start", isPresented: $failedToStart) {}

    }

}


